Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: net/dns/dns_protocol.h

Issue 1535363003: Switch to standard integer types in net/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: stddef Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/dns/dns_hosts.cc ('k') | net/dns/dns_query.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/dns/dns_protocol.h
diff --git a/net/dns/dns_protocol.h b/net/dns/dns_protocol.h
index f3f9292009a4ed4ef205480d79ad37e4816490e5..3b421ae790894ad6170378467716627a20e2cdf0 100644
--- a/net/dns/dns_protocol.h
+++ b/net/dns/dns_protocol.h
@@ -5,15 +5,16 @@
#ifndef NET_DNS_DNS_PROTOCOL_H_
#define NET_DNS_DNS_PROTOCOL_H_
-#include "base/basictypes.h"
+#include <stdint.h>
+
#include "net/base/net_export.h"
namespace net {
namespace dns_protocol {
-static const uint16 kDefaultPort = 53;
-static const uint16 kDefaultPortMulticast = 5353;
+static const uint16_t kDefaultPort = 53;
+static const uint16_t kDefaultPortMulticast = 5353;
// DNS packet consists of a header followed by questions and/or answers.
// For the meaning of specific fields, please see RFC 1035 and 2535
@@ -73,28 +74,28 @@ static const uint16 kDefaultPortMulticast = 5353;
#pragma pack(push)
#pragma pack(1)
// On-the-wire header. All uint16 are in network order.
// Used internally in DnsQuery and DnsResponse.
struct NET_EXPORT_PRIVATE Header {
- uint16 id;
- uint16 flags;
- uint16 qdcount;
- uint16 ancount;
- uint16 nscount;
- uint16 arcount;
+ uint16_t id;
+ uint16_t flags;
+ uint16_t qdcount;
+ uint16_t ancount;
+ uint16_t nscount;
+ uint16_t arcount;
};
#pragma pack(pop)
-static const uint8 kLabelMask = 0xc0;
-static const uint8 kLabelPointer = 0xc0;
-static const uint8 kLabelDirect = 0x0;
-static const uint16 kOffsetMask = 0x3fff;
+static const uint8_t kLabelMask = 0xc0;
+static const uint8_t kLabelPointer = 0xc0;
+static const uint8_t kLabelDirect = 0x0;
+static const uint16_t kOffsetMask = 0x3fff;
// In MDns the most significant bit of the rrclass is designated as the
// "cache-flush bit", as described in http://www.rfc-editor.org/rfc/rfc6762.txt
// section 10.2.
-static const uint16 kMDnsClassMask = 0x7FFF;
+static const uint16_t kMDnsClassMask = 0x7FFF;
static const int kMaxNameLength = 255;
@@ -107,34 +108,33 @@ static const int kMaxUDPSize = 512;
static const int kMaxMulticastSize = 9000;
// DNS class types.
-static const uint16 kClassIN = 1;
+static const uint16_t kClassIN = 1;
// DNS resource record types. See
// http://www.iana.org/assignments/dns-parameters
-static const uint16 kTypeA = 1;
-static const uint16 kTypeCNAME = 5;
-static const uint16 kTypePTR = 12;
-static const uint16 kTypeTXT = 16;
-static const uint16 kTypeAAAA = 28;
-static const uint16 kTypeSRV = 33;
-static const uint16 kTypeNSEC = 47;
-
+static const uint16_t kTypeA = 1;
+static const uint16_t kTypeCNAME = 5;
+static const uint16_t kTypePTR = 12;
+static const uint16_t kTypeTXT = 16;
+static const uint16_t kTypeAAAA = 28;
+static const uint16_t kTypeSRV = 33;
+static const uint16_t kTypeNSEC = 47;
// DNS rcode values.
-static const uint8 kRcodeMask = 0xf;
-static const uint8 kRcodeNOERROR = 0;
-static const uint8 kRcodeFORMERR = 1;
-static const uint8 kRcodeSERVFAIL = 2;
-static const uint8 kRcodeNXDOMAIN = 3;
-static const uint8 kRcodeNOTIMP = 4;
-static const uint8 kRcodeREFUSED = 5;
+static const uint8_t kRcodeMask = 0xf;
+static const uint8_t kRcodeNOERROR = 0;
+static const uint8_t kRcodeFORMERR = 1;
+static const uint8_t kRcodeSERVFAIL = 2;
+static const uint8_t kRcodeNXDOMAIN = 3;
+static const uint8_t kRcodeNOTIMP = 4;
+static const uint8_t kRcodeREFUSED = 5;
// DNS flags.
-static const uint16 kFlagResponse = 0x8000;
-static const uint16 kFlagRA = 0x80;
-static const uint16 kFlagRD = 0x100;
-static const uint16 kFlagTC = 0x200;
-static const uint16 kFlagAA = 0x400;
+static const uint16_t kFlagResponse = 0x8000;
+static const uint16_t kFlagRA = 0x80;
+static const uint16_t kFlagRD = 0x100;
+static const uint16_t kFlagTC = 0x200;
+static const uint16_t kFlagAA = 0x400;
} // namespace dns_protocol
« no previous file with comments | « net/dns/dns_hosts.cc ('k') | net/dns/dns_query.h » ('j') | no next file with comments »
@@ -73,28 +74,28 @@ static const uint16 kDefaultPortMulticast = 5353;
#pragma pack(push)
#pragma pack(1)
-// On-the-wire header. All uint16 are in network order.
+// On-the-wire header. All uint16_t are in network order.
// Used internally in DnsQuery and DnsResponse.
struct NET_EXPORT_PRIVATE Header {

Powered by Google App Engine
This is Rietveld 408576698